@@ -1,7 +1,7 @@
 //
 // RapMap - Rapid and accurate mapping of short reads to transcriptomes using
 // quasi-mapping.
-// Copyright (C) 2015, 2016 Rob Patro, Avi Srivastava, Hirak Sarkar
+// Copyright (C) 2015, 2016, 2017 Rob Patro, Avi Srivastava, Hirak Sarkar
 //
 // This file is part of RapMap.
 //
@@ -70,6 +70,9 @@
 
 #include "IndexHeader.hpp"
 
+// sha functionality
+#include "picosha2.h"
+
 #include <chrono>
 
 using single_parser = fastx_parser::FastxParser<fastx_parser::ReadSeq>;
@@ -311,7 +314,7 @@ bool buildHash(const std::string& outputDir, std::string& concatText,
             /*
             IndexT len = stop - start;
             bool overflow = (len >= std::numeric_limits<uint8_t>::max());
-            uint8_t blen = overflow ? std::numeric_limits<uint8_t>::max() : 
+            uint8_t blen = overflow ? std::numeric_limits<uint8_t>::max() :
                 static_cast<uint8_t>(len);
             khash[bits] = {start, blen};
             if (overflow) {
@@ -371,7 +374,7 @@ bool buildHash(const std::string& outputDir, std::string& concatText,
           /*
           IndexT len = stop - start;
           bool overflow = (len >= std::numeric_limits<uint8_t>::max());
-          uint8_t blen = overflow ? std::numeric_limits<uint8_t>::max() : 
+          uint8_t blen = overflow ? std::numeric_limits<uint8_t>::max() :
               static_cast<uint8_t>(len);
           khash[bits] = {start, blen};
           if (overflow) {
@@ -411,7 +414,7 @@ bool buildHash(const std::string& outputDir, std::string& concatText,
       /*
       IndexT len = stop - start;
       bool overflow = (len >= std::numeric_limits<uint8_t>::max());
-      uint8_t blen = overflow ? std::numeric_limits<uint8_t>::max() : 
+      uint8_t blen = overflow ? std::numeric_limits<uint8_t>::max() :
           static_cast<uint8_t>(len);
       khash[mer.get_bits(0, 2 * k)] = {start, blen};
       if (overflow) {
@@ -437,20 +440,22 @@ bool buildHash(const std::string& outputDir, std::string& concatText,
 // available. A job behaves like a pointer to the type
 // jellyfish::sequence_list (see whole_sequence_parser.hpp).
 template <typename ParserT> //, typename CoverageCalculator>
-void indexTranscriptsSA(ParserT* parser, std::string& outputDir,
+void indexTranscriptsSA(ParserT* parser,
+                        std::string& outputDir,
                         bool noClipPolyA, bool usePerfectHash,
-                        uint32_t numHashThreads, 
+                        uint32_t numHashThreads,
                         std::string& sepStr,
                         std::mutex& iomutex,
                         std::shared_ptr<spdlog::logger> log) {
-  // Seed with a real random value, if available
-  std::random_device rd;
-
   // Create a random uniform distribution
-  std::default_random_engine eng(rd());
+  std::default_random_engine eng(271828);
 
   std::uniform_int_distribution<> dis(0, 3);
 
+  // Hashers for getting txome signature
+  picosha2::hash256_one_by_one seqHasher; seqHasher.init();
+  picosha2::hash256_one_by_one nameHasher; nameHasher.init();
+
   uint32_t n{0};
   uint32_t k = rapmap::utils::my_mer::k();
   std::vector<std::string> transcriptNames;
@@ -481,6 +486,9 @@ void indexTranscriptsSA(ParserT* parser, std::string& outputDir,
   // rsdic::RSDicBuilder rsdb;
   std::vector<uint64_t>
       onePos; // Positions in the bit array where we should write a '1'
+  // remember the initial lengths (e.g., before clipping etc., of all transcripts)
+  std::vector<uint32_t> completeLengths;
+  // the stream of transcript sequence
   fmt::MemoryWriter txpSeqStream;
   {
     ScopedTimer timer;
@@ -496,7 +504,10 @@ void indexTranscriptsSA(ParserT* parser, std::string& outputDir,
                            [](const char a) -> bool { return !(isprint(a)); }),
             readStr.end());
 
+        seqHasher.process(readStr.begin(), readStr.end());
+
         uint32_t readLen = readStr.size();
+        uint32_t completeLen = readLen;
         // First, replace non ATCG nucleotides
         for (size_t b = 0; b < readLen; ++b) {
           readStr[b] = ::toupper(readStr[b]);
@@ -550,11 +561,14 @@ void indexTranscriptsSA(ParserT* parser, std::string& outputDir,
 
           // The name of the current transcript
           auto& recHeader = read.name;
-          transcriptNames.emplace_back(
-                                       recHeader.substr(0, recHeader.find_first_of(sepStr)));//" \t")));
+          auto processedName = recHeader.substr(0, recHeader.find_first_of(sepStr));
+          transcriptNames.emplace_back(processedName);
+          nameHasher.process(processedName.begin(), processedName.end());
 
           // The position at which this transcript starts
           transcriptStarts.push_back(currIndex);
+          // The un-molested length of this transcript
+          completeLengths.push_back(completeLen);
 
           txpSeqStream << readStr;
           txpSeqStream << '$';
@@ -628,6 +642,7 @@ void indexTranscriptsSA(ParserT* parser, std::string& outputDir,
     }
     // seqArchive(positionIDs);
     seqArchive(concatText);
+    seqArchive(completeLengths);
     std::cerr << "done\n";
   }
   seqStream.close();
@@ -688,9 +703,22 @@ void indexTranscriptsSA(ParserT* parser, std::string& outputDir,
     }
   }
 
-  std::string indexVersion = "q3";
-  IndexHeader header(IndexType::QUASI, indexVersion, true, k, largeIndex,
+  seqHasher.finish();
+  nameHasher.finish();
+
+  std::string indexVersion = "q5";
+  IndexHeader header(IndexType::QUASI,
+                     indexVersion,
+                     true, k, largeIndex,
                      usePerfectHash);
+  // Set the hash info
+  std::string seqHash;
+  std::string nameHash;
+  picosha2::get_hash_hex_string(seqHasher, seqHash);
+  picosha2::get_hash_hex_string(nameHasher, nameHash);
+  header.setSeqHash(seqHash);
+  header.setNameHash(nameHash);
+
   // Finally (since everything presumably succeeded) write the header
   std::ofstream headerStream(outputDir + "header.json");
   {
@@ -794,5 +822,14 @@ int rapMapSAIndex(int argc, char* argv[]) {
   std::mutex iomutex;
   indexTranscriptsSA(transcriptParserPtr.get(), indexDir, noClipPolyA,
                      usePerfectHash, numPerfectHashThreads, sepStr, iomutex, jointLog);
+
+  // Output info about the reference
+  std::ofstream refInfoStream(indexDir + "refInfo.json");
+  {
+    cereal::JSONOutputArchive archive(refInfoStream);
+    archive(cereal::make_nvp("ReferenceFiles", transcriptFiles));
+  }
+  refInfoStream.close();
+
   return 0;
 }
